==> qt-x11-opensource-src-4.0.1.tar.gz: qt-x11-opensource-src-4.0.1/src/plugins/sqldrivers/sqlite2/smain.cpp <==
/****************************************************************************
**
** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
**
** This file is part of the plugins of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#include <qsqldriverplugin.h>
#include <qstringlist.h>
#include "../../../../src/sql/drivers/sqlite2/qsql_sqlite2.h"

class QSQLite2DriverPlugin : public QSqlDriverPlugin
{
public:
    QSQLite2DriverPlugin();

    QSqlDriver* create(const QString &);
    QStringList keys() const;
};

QSQLite2DriverPlugin::QSQLite2DriverPlugin()
    : QSqlDriverPlugin()
{
}

QSqlDriver* QSQLite2DriverPlugin::create(const QString &name)
{
    if (name == QLatin1String("QSQLITE2")) {
        QSQLite2Driver* driver = new QSQLite2Driver();
        return driver;
    }
    return 0;
}

QStringList QSQLite2DriverPlugin::keys() const
{
    QStringList l;
    l  << QLatin1String("QSQLITE2");
    return l;
}

Q_EXPORT_PLUGIN(QSQLite2DriverPlugin)

==> qt-x11-opensource-src-4.1.0.tar.gz: qt-x11-opensource-src-4.1.0/src/plugins/sqldrivers/sqlite2/smain.cpp <==
/****************************************************************************
**
** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
**
** This file is part of the plugins of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#include <qsqldriverplugin.h>
#include <qstringlist.h>
#include "../../../../src/sql/drivers/sqlite2/qsql_sqlite2.h"

class QSQLite2DriverPlugin : public QSqlDriverPlugin
{
public:
    QSQLite2DriverPlugin();

    QSqlDriver* create(const QString &);
    QStringList keys() const;
};

QSQLite2DriverPlugin::QSQLite2DriverPlugin()
    : QSqlDriverPlugin()
{
}

QSqlDriver* QSQLite2DriverPlugin::create(const QString &name)
{
    if (name == QLatin1String("QSQLITE2")) {
        QSQLite2Driver* driver = new QSQLite2Driver();
        return driver;
    }
    return 0;
}

QStringList QSQLite2DriverPlugin::keys() const
{
    QStringList l;
    l  << QLatin1String("QSQLITE2");
    return l;
}

Q_EXPORT_STATIC_PLUGIN(QSQLite2DriverPlugin)
Q_EXPORT_PLUGIN2(qsqlite2, QSQLite2DriverPlugin)
